@@ -173,11 +173,32 @@ function createUser($userMgmt, $input, $authData) {
             'created_at' => date('c')
         ];
         
-        // Set resource limits if provided
+        // Set resource limits if provided, otherwise ensure defaults are set
         if (!empty($resources)) {
             $resourceResult = setUserResources($input['username'], $resources);
             if ($resourceResult) {
                 $userData['resources'] = $resources;
+            } else {
+                error_log("Failed to set custom resources for user: " . $input['username']);
+            }
+        } else {
+            // Ensure default resources exist (create_new_user should have set these, but verify)
+            $existingResources = getUserResources($input['username']);
+            if (!$existingResources) {
+                // If no resources exist, set basic defaults
+                $defaultResources = [
+                    'cpu_cores' => 0.5,
+                    'memory_mb' => 512,
+                    'disk_mb' => 1000,
+                    'email_accounts' => 0,
+                    'email_storage_mb' => 1000
+                ];
+                $resourceResult = setUserResources($input['username'], $defaultResources);
+                if ($resourceResult) {
+                    $userData['resources'] = $defaultResources;
+                }
+            } else {
+                $userData['resources'] = $existingResources;
             }
         }
         
@@ -273,9 +294,8 @@ function getUserResources($username) {
         $db->exec("USE whp");
         
         $stmt = $db->prepare("
-            SELECT max_cpu_allowance, max_memory_allowance, max_disk_space, max_domains, 
-                   max_sites, max_email_accounts, max_email_storage_mb, max_databases, 
-                   api_enabled, api_rate_limit
+            SELECT max_cpu_allowance, max_memory_allowance, max_disk_space, 
+                   max_email_accounts, max_email_storage_mb
             FROM client_allowances 
             WHERE username = ?
         ");
@@ -284,18 +304,13 @@ function getUserResources($username) {
         $result = $stmt->fetch(PDO::FETCH_ASSOC);
         
         if ($result) {
-            // Map database column names back to API field names
+            // Map database column names back to API field names (only WHP-tracked resources)
             return [
                 'cpu_cores' => $result['max_cpu_allowance'],
                 'memory_mb' => $result['max_memory_allowance'],
                 'disk_mb' => $result['max_disk_space'],
-                'domains' => $result['max_domains'],
-                'sites' => $result['max_sites'],
                 'email_accounts' => $result['max_email_accounts'],
-                'email_storage_mb' => $result['max_email_storage_mb'],
-                'databases' => $result['max_databases'],
-                'api_enabled' => $result['api_enabled'],
-                'api_rate_limit' => $result['api_rate_limit']
+                'email_storage_mb' => $result['max_email_storage_mb']
             ];
         }
         
@@ -324,18 +339,13 @@ function setUserResources($username, $resources) {
             $fields = [];
             $values = [];
             
-            // Map API field names to database column names
+            // Map API field names to database column names (only WHP-tracked resources)
             $fieldMapping = [
                 'cpu_cores' => 'max_cpu_allowance',
                 'memory_mb' => 'max_memory_allowance',
                 'disk_mb' => 'max_disk_space',
-                'domains' => 'max_domains',
-                'sites' => 'max_sites',
                 'email_accounts' => 'max_email_accounts',
-                'email_storage_mb' => 'max_email_storage_mb',
-                'databases' => 'max_databases',
-                'api_enabled' => 'api_enabled',
-                'api_rate_limit' => 'api_rate_limit'
+                'email_storage_mb' => 'max_email_storage_mb'
             ];
             
             foreach ($fieldMapping as $apiField => $dbColumn) {
