@@ -602,4 +602,12 @@ class usermgmt {
         return $users;
     }
 
+    /**
+     * Check if a user exists on the system
+     */
+    public function user_exists($username) {
+        $id = shell_exec("/usr/bin/id -u " . escapeshellarg($username) . " 2>/dev/null");
+        return is_numeric(trim($id));
+    }
+
 }
\ No newline at end of file
