@@ -120,7 +120,7 @@ if ($current_user) {
                         <?php endif; ?>
                     </div>
                 <?php else: ?>
-                    <div class="announcements-container flex-grow-1" style="max-height: calc(100vh - 400px); overflow-y: auto;">
+                    <div class="announcements-container flex-grow-1" style="overflow-y: auto;">
                         <?php foreach ($announcements as $announcement): ?>
                             <div class="announcement-item mb-3 p-3 border rounded <?php echo $announcement['pinned'] ? 'border-warning' : ''; ?>">
                                 <div class="d-flex justify-content-between align-items-start mb-2">
